<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="id">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Hilangkan bingkai jendela</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Putar ke arah vertikal</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Putar ke arah horizontal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Balikan</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Abu - abu</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Hitam-dan-putih</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Pindah ke Jendela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Pindah ke Layar Penuh</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Pindah ke Jendela</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Pindah ke Layar Penuh</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Persiapan program sukses.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Tutup jendela dan mulai ulang vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Selamat bersenang-senang dengan vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Pengelola berkas tidak ditemukan.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Mohon pasang pengelola berkas.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Peringatan</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Perekaman belum berjalan, ruang bebas diska tidak cukup.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Batas ruang bebas diska tercapai.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Batas dari ruang bebas diska</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Perekaman telah dihentikan, ruang bebas diska tidak cukup.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Jendela</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Manajer erkas tidak ditemukan</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Mohon pasang sebuah manajer berkas</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Kode sumber</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Halaman muka</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Terjemahan</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasi</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat.</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Daerah</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Bidangluas</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Pengelola berkas tidak ditemukan.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Mohon pasang pengelola berkas.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Lanjut</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Jeda</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Lanjut</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Pilih satu atau lebih perangkat.</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Putar ke arah horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Putar ke arah vertikal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Balikan</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Abu - abu</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Hitam-dan-putih</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Hilangkan bingkai jendela</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Pengaturan Kamera</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Daerah</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Atur ulang</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Pembesaran</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Hitung mundur</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Ukuran video:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Ruang bebas diska:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasi:</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Waktu Rekam:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frame</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Kodekvideo</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Kodekaudio</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Kualitas</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Jangan rekam kursor tetikus</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Jam</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Menit</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Mulai pengatur waktu</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Hentikan rekaman setelah</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Jam - Jam</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Menit</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Detik</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Jalur video</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Batas dari ruang bebas diska</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Tampilkan dalam baki sistem</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Detik menunggu sebelum merekam</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Memeriksa perubahan</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Bantuan</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Tersedia</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Tidak tersedia</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Mulai</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Lanjut</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Putar</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Balikan</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Abu - abu</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Putar rekaman terakhir</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Buka folder</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Kecilkan ketika rekaman dimulai</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Mulai mengecilkan</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Putar ke arah horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Putar ke arah vertikal</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Hitam-dan-putih</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Hilangkan bingkai jendela</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donasi</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Atur ulang semua pengaturan pada mulai berikutnya</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Hak cipta dan lisensi dari gambar - gambar</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>RekamLayar</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Pemutar</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Pencatatan</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Secara otomatis</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Buat gambar dari tab</translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Informasi lisensi</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>HIDUPKAN</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>MATIKAN</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Tombol-pintas umum</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Tombol pintas yang diterapkan.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Tombol pintas belum dipasang atau telah dipasang lebih dari sekali.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Apabila telah diterapkan namun tidak bekerja, bisa jadi sedang digunakan oleh program lain.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Jepret-gambar</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Jalursimpan-gambar</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Sembunyikan jendela</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>detik waktu tunggu prarekam</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Hak cipta dan lisensi dari gambar - gambar</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Putar</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tangguhkan</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Berhenti</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Buka Berkas</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Layar penuh</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Bingkai sebelumnya</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Bingkai berikutnya</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Bisu</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Pindah menu</translation>
    </message>
</context>
</TS>